@@ -73,7 +73,9 @@ async def get(path, params=None, base_url=tornado.options.options.data_server, r
             return result
 
 
-def sync_get(path, params=None, base_url=tornado.options.options.data_server, result_type="json", pack=False, **kwargs):
+def sync_get(path, params=None, base_url=None, result_type="json", pack=False, **kwargs):
+    if not base_url:
+        base_url = tornado.options.options.data_server
     res = requests.get(base_url + path, params=params, **kwargs)
     if result_type == "json":
         res = res.json()
@@ -91,8 +93,10 @@ def sync_get(path, params=None, base_url=tornado.options.options.data_server, re
 
 
 def sync_post(path, data=None,
-              base_url=tornado.options.options.data_server,
+              base_url=None,
               result_type="json", pack=False, **kwargs):
+    if not base_url:
+        base_url = tornado.options.options.data_server
     flag = kwargs.pop("flag", True)
     if flag:
         if not kwargs.get("headers"):
